@@ -10,7 +10,7 @@ class SAP:
         self.session = None
 
     # methods
-    def app(self):
+    def app():
         wmi_object = WMI()
         
         # checking if SAP is already open
@@ -23,7 +23,6 @@ class SAP:
         # connecting scripts to SAP
         return GetObject("SAPGUI").GetScriptingEngine
 
-    @staticmethod
     def connect_sap(self, connection_name):
         # opening given SAP environment
         self.connection = SAP.app().OpenConnection(connection_name)
@@ -36,6 +35,9 @@ class SAP:
         except:
             pass
 
+        self.session.findById("wnd[0]/tbar[0]/okcd").text = "/n"
+        self.session.findById("wnd[0]").sendVKey(0)
+        self.session.findById("wnd[0]/usr/btnSTARTBUTTON").press()
         self.session.findById("wnd[0]").sendVKey(0)
 
         return self.session
